/*
 * Copyright 2009-2015 Dovetailed Technologies, LLC.
 *
 * Licensed under the accompanying Co:Z Target System Toolkit Source License Agreement (the "License");
 * you may not use this file except in compliance with the License.
 *
 */

/**
 * Defines various constants used by CoZ client and server code
 */

#ifndef _COZ_CONSTANTS
#define _COZ_CONSTANTS

// The CozClient -> CozServer protocol version
static const int  COZ_PROTOCOL_VERSION = 2;   // In version 2, CoZClient will no longer do a shutdown(SHUT_WR) on the socket
											  // if io_config.std_in == IO_CONFIG_NONE (no stdin).   The server will instead
											  // do a shutdown(SHUT_RD) on the socket.


// Exit codes, also thrown as exceptions

static const int RC_OK         		= 0;      // the main method returned normally 
static const int RC_INPUT_ERROR		= 101;    // user input or config error
static const int RC_SYSTEM_ERROR 	= 102;    // system api error other than IO
static const int RC_IO_ERROR 		= 103;    
static const int RC_CONVERT_ERROR 	= 104;
static const int RC_TARGET_KILLED   = 105;
static const int RC_AUTH_ERROR      = 106;
static const int RC_AGENT_ERROR     = 107;
static const int RC_CHILD_ERROR		= 108;

#define SYS_UTIL_SYSTEM_ERROR RC_SYSTEM_ERROR
#define SYS_UTIL_IO_ERROR RC_IO_ERROR

#define ENV_COZ_AUTH_TOKEN 				"COZ_AUTH_TOKEN"
#define ENV_COZ_CONNECT_TIMEOUT_SEC 	"COZ_CONNECT_TIMEOUT_SEC"
#define ENV_COZ_SSH_CONNECT_TIMEOUT_SEC "COZ_SSH_CONNECT_TIMEOUT_SEC"
#define ENV_COZ_SSH_CMD					"COZ_SSH_CMD"
#define ENV_COZ_SSH_OPTS             	"COZ_SSH_OPTS"     // setting this also enables type SSH connection
#define ENV_COZ_SSH_SUBSYS              "COZ_SSH_SUBSYS"
#define ENV_COZ_SERVER_HOST				"COZ_SERVER_HOST"
#define ENV_COZ_SERVER_PORT				"COZ_SERVER_PORT"
#define ENV_COZ_SERVER_PROTOCOL_VERSION	"COZ_SERVER_PROTOCOL_VERSION"
#define ENV_COZ_LOG						"COZ_LOG"
#define ENV_COZ_DEFAULT_LOGSTREAM		"COZ_DEFAULT_LOGSTREAM" 
#define ENV_CLIENT_CODEPAGE             "COZ_CLIENT_CODEPAGE"

#define ENV_CLIENT_OPSYS                "COZ_CLIENT_OPSYS"
#define ENV_CLIENT_OPSYS_WINDOWS        "WINDOWS"
#define ENV_CLIENT_OPSYS_POSIX          "POSIX"

#define ENV_COZ_ERRPT_FD                "COZ_ERRPT_FD"

#define ENV_COZ_CONTROL_SESSION			"COZ_CONTROL_SESSION"
#define ENV_COZ_CONTROL_PATH			"COZ_CONTROL_PATH"
#define ENV_COZ_LOG_CMD     			"COZ_LOG_CMD"
#define ENV_COZ_LOG_CMD_DUP     		"COZ_LOG_CMD_DUP"   //when true, duplicate fromdsn/todsn/cozclient stderr to dspipes session log

#define COZ_AGENT_COMPLETION_MSG		"CoZAgent: completed with RC="
#define COZ_AGENT_VERSION_MSG			"CoZAgent: version="


const int  STDIN_FD  = 0;
const int  STDOUT_FD = 1;
const int  STDERR_FD = 2;
const int  ERRPT_FD  = 3;  // server only 

const int READ_END   = 0;
const int WRITE_END  = 1;

#endif  /* _COZ_CONSTANTS */
